@@ -45,27 +45,6 @@ install_tinytex = function(
     unlink(dir, recursive = TRUE)
     user_dir = normalizePath(dir, mustWork = FALSE)
   }
-  tweak_path()
-  msg = if (tlmgr_available()) {
-    if (!is_tinytex()) {
-      system2('tlmgr', '--version')
-      c(
-        'Detected an existing tlmgr at ', Sys.which('tlmgr'), '. ',
-        'It seems TeX Live has been installed (check tinytex::tinytex_root()). '
-      )
-    }
-  } else if (Sys.which('pdftex') != '') {
-    system2('pdftex', '--version')
-    c(
-      'Detected an existing LaTeX distribution (e.g., pdftex is at ',
-      Sys.which('pdftex'), '). '
-    )
-  }
-  if (length(msg)) warning(
-    msg, 'You are recommended to uninstall it, although TinyTeX should work well alongside ',
-    'another LaTeX distribution if a LaTeX document is compiled through tinytex::latexmk().',
-    call. = FALSE
-  )
 
   https = grepl('^https://', repository)
   repository = normalize_repo(repository)
@@ -291,9 +270,18 @@ symlink_root = function(path) {
   in_dir(dirname(path), symlink_root(path2))
 }
 
-# it should be TinyTeX if the root dir name is [.]TinyTeX, or a line like this
-# can be found in fmtutil.cnf:
-# Generated by */TinyTeX/bin/x86_64-darwin/tlmgr on Thu Sep 17 07:13:28 2020
+#' Check if the LaTeX installation is TinyTeX
+#'
+#' First find the root directory of the installation via
+#' \code{\link{tinytex_root}()}. Then check if the directory name is
+#' \code{"tinytex"} (case-insensitive). If not, further check if the first line
+#' of the file \file{texmf-dist/web2c/fmtutil.cnf} under the directory contains
+#' \code{"TinyTeX"} or \code{".TinyTeX"}. If the binary version of TinyTeX was
+#' installed, \file{fmtutil.cnf} should contain a line like \samp{Generated by
+#' */TinyTeX/bin/x86_64-darwin/tlmgr on Thu Sep 17 07:13:28 2020}.
+#' @return A logical value indicating if the LaTeX installation is TinyTeX.
+#' @export
+#' @examples tinytex::is_tinytex()
 is_tinytex = function() tryCatch({
   root = tinytex_root()
   root != '' && (gsub('^[.]', '', tolower(basename(root))) == 'tinytex' || any(grepl(
