@@ -378,6 +378,8 @@ check_unicode = function(x) {
 # whether a LaTeX log file contains LaTeX or package (e.g. babel) warnings
 latex_warning = function(file, show = getOption('tinytex.latexmk.warning', TRUE)) {
   if (!file.exists(file)) return()
+  # if the option tinytex.latexmk.warning = FALSE, delete the log in latexmk_emu()
+  if (!show && missing(show)) return()
   x = readLines(file, warn = FALSE)
   if (length(i <- grep('^(LaTeX|Package [[:alnum:]]+) Warning:', x)) == 0) return()
   # these warnings may be okay (our Pandoc LaTeX template in rmarkdown may need an update)
@@ -568,7 +570,7 @@ miss_font = function() {
 
 font_ext = function(x) {
   i = !grepl('[.]', x)
-  x[i] = paste0(x[i], '[.](tfm|afm|mf|otf)')
+  x[i] = paste0(x[i], '(-(Bold|Italic|Regular).*)?[.](tfm|afm|mf|otf|ttf)')
   x
 }
 
@@ -593,6 +595,11 @@ fc_cache = function(args = c('-v', '-r')) {
   system2('fc-cache', args)
 }
 
+# refresh/update/regenerate everything
+refresh_all = function(...) {
+  fc_cache(); fmtutil(...); updmap(...); texhash()
+}
+
 # look up files in the Kpathsea library, e.g., kpsewhich('Sweave.sty')
 kpsewhich = function(filename, options = character()) {
   tweak_path()
